unit EditorHackU;

interface

implementation

uses
  Forms, SysUtils, ComCtrls, Menus;

type
  TEditorHack = class(TObject)
  private
    //New menu item
    FEditorItem: TMenuItem;
  protected
    //Event handler for new menu item
    procedure DoEditorItemClick(Sender: TObject);
    //Routine that changes the state of the editor window
    procedure SetEditorItem(Value: Boolean);
  public
    constructor Create;
    destructor Destroy; override;
  end;

constructor TEditorHack.Create;
var
  //Delphi's Tools menu
  ToolsMenu: TMenuItem;
begin
  inherited;
  //Find the Tools menu
  ToolsMenu := Application.MainForm.FindComponent('ToolsMenu') as TMenuItem;
  if Assigned(ToolsMenu) then
  begin
    //Make new menu item
    FEditorItem := NewItem('&Multiline Editor Tabs',
      0, False, True, DoEditorItemClick, 0, '');
    //Insert new menu item
    ToolsMenu.Insert(2, FEditorItem);
  end
end;

destructor TEditorHack.Destroy;
begin
  //Restore normal editor appearance
  SetEditorItem(False);
  //Destroy editor option menu item
  FEditorItem.Free;
  FEditorItem := nil;
  inherited
end;

procedure TEditorHack.DoEditorItemClick(Sender: TObject);
begin
  //When user toggles editor menu option, set
  //checkmark and set editor state accordingly
  with Sender as TMenuItem do
  begin
    Checked := not Checked;
    SetEditorItem(Checked)
  end
end;

procedure TEditorHack.SetEditorItem(Value: Boolean);
var
  Loop: Integer;
  Tab: TTabControl;
begin
  with Screen do
    //Loop through all Delphi's forms on-screen
    for Loop := 0 to Pred(FormCount) do
      //If we find an editor....
      if CompareText(Forms[Loop].ClassName, 'TEditWindow') = 0 then
        with Forms[Loop] as TForm do
        begin
          //...try and find the tab control...
          Tab := FindComponent('TabControl') as TTabControl;
          if Assigned(Tab) then
            //...and set it as requested
            Tab.MultiLine := Value
        end
end;

var
  EditorHack: TEditorHack;

initialization
  EditorHack := TEditorHack.Create
finalization
  EditorHack.Free
end.